@@ -19,6 +19,8 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #
 #
+import sys
+
 import pytest
 
 from bluetooth_mesh.messages.generic.battery import *
@@ -27,13 +29,13 @@ valid = [
     # fmt: off
     pytest.param(
         b'\x82\x23',
-        GenericBatteryOpcode.BATTERY_GET,
+        GenericBatteryOpcode.GENERIC_BATTERY_GET,
         dict(),
-        id="BATTERY_GET"
+        id="GENERIC_BATTERY_GET"
     ),
     pytest.param(
         b'\x82\x24\x32\xb4\x00\x00\xfe\xfe\x00\x62',
-        GenericBatteryOpcode.BATTERY_STATUS,
+        GenericBatteryOpcode.GENERIC_BATTERY_STATUS,
         dict(
             battery_level=50,
             time_to_discharge=0xb4,
@@ -45,15 +47,15 @@ valid = [
                 battery_serviceability_flags=GenericBatteryFlagsServiceability.BATTERY_NOT_REQUIRE_SERVICE
             )
         ),
-        id="BATTERY_STATUS"
+        id="GENERIC_BATTERY_STATUS"
     ),
     pytest.param(
         b'\x82\x24\xff\xbb\xaa\x00\xff\xff\xff\xdb',
-        GenericBatteryOpcode.BATTERY_STATUS,
+        GenericBatteryOpcode.GENERIC_BATTERY_STATUS,
         dict(
-            battery_level=None,
+            battery_level=float(sys.float_info.max),
             time_to_discharge=0xaabb,
-            time_to_charge=None,
+            time_to_charge=float(sys.float_info.max),
             flags=dict(
                 battery_presence_flags=GenericBatteryFlagsPresence.BATTERY_PRESENCE_UNKNOWN,
                 battery_indicator_flags=GenericBatteryFlagsIndicator.BATTERY_CHARGE_GOOD,
@@ -61,7 +63,7 @@ valid = [
                 battery_serviceability_flags=GenericBatteryFlagsServiceability.BATTERY_SERVICEABILITY_UNKNOWN
             )
         ),
-        id="BATTERY_STATUS"
+        id="GENERIC_BATTERY_STATUS"
     ),
     # fmt: on
 ]
