@@ -187,9 +187,13 @@ def test_build_invalid(message, decoded, exception):
         message.build(obj=decoded)
 
 
-def test_build_health_message():
+@pytest.mark.parametrize("key", ["params", "health_attention_set"])
+def test_build_health_message(key):
     data = HealthMessage.build(
-        dict(opcode=HealthOpcode.ATTENTION_SET, params=dict(attention=6))
+        {
+            "opcode": HealthOpcode.HEALTH_ATTENTION_SET,
+            key: dict(attention=6),
+        }
     )
 
     assert data == bytes.fromhex("800506")
@@ -198,7 +202,10 @@ def test_build_health_message():
 def test_parse_health_message():
     msg = HealthMessage.parse(bytes.fromhex("800506"))
 
-    assert msg == dict(opcode=HealthOpcode.ATTENTION_SET, params=dict(attention=6))
+    assert msg == dict(
+        opcode=HealthOpcode.HEALTH_ATTENTION_SET,
+        health_attention_set=dict(attention=6),
+    )
 
 
 def test_parse_health_message_bad_opcode():
